@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dwindowmanagerhelper.h"
 #include "dforeignwindow.h"
@@ -151,183 +134,196 @@ class DWindowManagerHelper_ : public DWindowManagerHelper {};
 Q_GLOBAL_STATIC(DWindowManagerHelper_, wmhGlobal)
 
 /*!
- * \~chinese \class DWindowManagerHelper
- * \~chinese \brief 提供与窗口管理器交互的接口，同 \a DPlatformWindowHandle 依赖 dxcb 插件。
- * \~chinese dxcb 插件抽象出所有需要和X11平台交互的接口以供上层调用，DTK 使用插件中提供的接口再
- * \~chinese 次封装提供给应用程序使用，从设计角度讲，DTK库中不应该直接使用任何跟平台相关的接口
- * \~chinese （如：X11、Wayland、Windows），在这样的结构支撑下，在一个新的平台上，只需要提供和
- * \~chinese dxcb 同样的接口，DTK应用即可无缝迁移。
- * \~chinese \sa \href{https://github.com/linuxdeepin/qt5dxcb-plugin/,dxcb插件}
- * \~chinese \sa DApplication::loadDXcbPlugin
- * \~chinese \sa DApplication::isDXcbPlatform
- * \~chinese \sa DPlatformWindowHandle
+  \class Dtk::Gui::DWindowManagerHelper
+  \inmodule dtkgui
+  \brief 提供与窗口管理器交互的接口，同 \a DPlatformWindowHandle 依赖 dxcb 插件.
+
+  dxcb 插件抽象出所有需要和X11平台交互的接口以供上层调用，DTK 使用插件中提供的接口再
+  次封装提供给应用程序使用，从设计角度讲，DTK库中不应该直接使用任何跟平台相关的接口
+  （如：X11、Wayland、Windows），在这样的结构支撑下，在一个新的平台上，只需要提供和
+  dxcb 同样的接口，DTK应用即可无缝迁移。
+  \sa {https://github.com/linuxdeepin/qt5dxcb-plugin/}{dxcb插件}
+  \sa Dtk::Widget::DApplication::loadDXcbPlugin
+  \sa Dtk::Widget::DApplication::isDXcbPlatform
+  \sa Dtk::Widget::DPlatformWindowHandle
  */
 
 /*!
- * \~chinese \property DWindowManagerHelper::hasBlurWindow
- * \~chinese \brief 窗口管理器是否支持窗口背景模糊特效
- * \~chinese \note 在 dxcb 插件中目前只支持 deepin-wm 和 kwin 这两种窗管的模糊特效
- * \~chinese \note 只读
+  \property DWindowManagerHelper::hasBlurWindow
+  \brief 窗口管理器是否支持窗口背景模糊特效
+  \note 在 dxcb 插件中目前只支持 deepin-wm 和 kwin 这两种窗管的模糊特效
+  \note 只读
  */
 
 /*!
- * \~chinese \property DWindowManagerHelper::hasComposite
- * \~chinese \brief 窗口管理器是否支持混成效果。如果不支持混成，则表示所有窗口的背景都不能透明，
- * \~chinese 随之而来也不会有窗口阴影等效果，不规则窗口的边缘也会存在锯齿。
- * \~chinese \note 只读
+  \property DWindowManagerHelper::hasComposite
+  \brief 窗口管理器是否支持混成效果。如果不支持混成，则表示所有窗口的背景都不能透明，
+  随之而来也不会有窗口阴影等效果，不规则窗口的边缘也会存在锯齿。
+  \note 只读
  */
 
 /*!
- * \~chinese \property DWindowManagerHelper::hasNoTitlebar
- * \~chinese \brief 窗口管理器是否支持隐藏窗口标题栏。如果支持，则 DPlatformWindowHandle::enableDXcbForWindow
- * \~chinese 会优先使用此方法支持自定义窗口标题栏。
- * \~chinese \note 只读
- * \~chinese \sa DPlatformWindowHandle::enableNoTitlebarForWindow
+  \property DWindowManagerHelper::hasNoTitlebar
+  \brief 窗口管理器是否支持隐藏窗口标题栏。如果支持，则 DPlatformWindowHandle::enableDXcbForWindow
+  会优先使用此方法支持自定义窗口标题栏。
+  \note 只读
+  \sa Dtk::Gui::DPlatformHandle::setEnabledNoTitlebarForWindow
  */
 
 /*!
- * \~chinese \property DWindowManagerHelper::hasWallpaperEffect
- * \~chinese \brief 窗口管理器是否支持窗口背景特效绘制。如果支持，则 绘制背景到透明窗口
- * \~chinese 会使用此方法开启特效窗口壁纸背景绘制。
- * \~chinese \note 只读
- * \~chinese \sa DPlatformWindowHandle::hasWallpaperEffectChanged
+  \property DWindowManagerHelper::hasWallpaperEffect
+  \brief 窗口管理器是否支持窗口背景特效绘制。如果支持，则 绘制背景到透明窗口
+  会使用此方法开启特效窗口壁纸背景绘制。
+  \note 只读
+  \sa hasWallpaperEffectChanged()
  */
 
 /*!
- * \~chinese \enum DWindowManagerHelper::MotifFunction
- * \~chinese MotifFunction::MotifFunction 窗口管理器对窗口所能控制的行为
- *
- * \~chinese \var DWindowManagerHelper::FUNC_RESIZE DWindowManagerHelper::FUNC_RESIZE
- * \~chinese 控制窗口大小。如果存在此标志，则窗口管理器可以改变窗口大小（如使用鼠标拖拽窗口边缘），
- * \~chinese 否则无法通过外部行为调整窗口大小。
- * \~chinese \code
- * DMainWindow w;
- *
- * w.resize(400, 200);
- * w.show();
- * DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_RESIZE, false);
- * \endcode
- * \~chinese \image html disable_resize_function.gif
- * \~chinese \note 普通窗口默认存在此标志，对于 Qt::Popup 和 Qt::BypassWindowManagerHint
- * \~chinese 类型的窗口，不受此标志位影响
- * \~chinese \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
- * \~chinese \note 对于使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- * \~chinese \sa DPlatformWindowHandle::enableDXcbForWindow
- * \~chinese \sa DPlatformWindowHandle::isEnabledDXcb
- *
- * \~chinese \var DWindowManagerHelper::FUNC_MOVE DWindowManagerHelper::FUNC_MOVE
- * \~chinese 控制窗口位置。如果存在此标志，则窗口管理器可以移动窗口（如使用鼠标拖动标题栏），否则
- * \~chinese 无法通过外部行为移动窗口位置。
- * \~chinese \code
- * DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_MOVE, false);
- * \endcode
- * \~chinese \image html disable_move_function.gif
- * \~chinese \var DWindowManagerHelper::FUNC_MINIMIZE DWindowManagerHelper::FUNC_MINIMIZE
- * \~chinese 最小化窗口。如果存在此标志，则窗口可以被最小化（如点击标题栏的最小化按钮），否则无法
- * \~chinese 通过外部行为最小化窗口。
- * \~chinese \code
- * DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_MINIMIZE, false);
- * \endcode
- * \~chinese \image html disable_minimize_function.gif
- * \~chinese \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
- *
- * \~chinese \var DWindowManagerHelper::FUNC_MAXIMIZE DWindowManagerHelper::FUNC_MAXIMIZE
- * \~chinese 最大化窗口。如果存在此标志，则窗口可以被最大化（如点击标题栏的最大化按钮），否则无法
- * \~chinese 通过外部行为最大化窗口。
- * \~chinese \code
- * DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_MAXIMIZE, false);
- * \endcode
- * \~chinese \image html disable_maximize_function.gif
- * \~chinese \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
- *
- * \~chinese \var DWindowManagerHelper::FUNC_CLOSE DWindowManagerHelper::FUNC_CLOSE
- * \~chinese 关闭窗口。如果存在此标志，则窗口可以被关闭（如点击标题栏的关闭按钮或使用Alt+F4快捷键），
- * \~chinese 否则无法通过外部行为关闭窗口。
- * \~chinese \code
- * DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_CLOSE, false);
- * \endcode
- * \~chinese \image html disable_close_function.gif
- * \~chinese \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
- *
- * \~chinese \var DWindowManagerHelper::FUNC_ALL DWindowManagerHelper::FUNC_ALL
- * \~chinese 所有功能性行为
+  \enum Dtk::Gui::DWindowManagerHelper::MotifFunction
+  MotifFunction::MotifFunction 窗口管理器对窗口所能控制的行为
+
+  \value FUNC_RESIZE
+  控制窗口大小。如果存在此标志，则窗口管理器可以改变窗口大小（如使用鼠标拖拽窗口边缘），
+  否则无法通过外部行为调整窗口大小。
+  \code
+  DMainWindow w;
+
+  w.resize(400, 200);
+  w.show();
+  DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_RESIZE, false);
+  \endcode
+  \image disable_resize_function.gif
+  \note 普通窗口默认存在此标志，对于 Qt::Popup 和 Qt::BypassWindowManagerHint
+  类型的窗口，不受此标志位影响
+  \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
+  \note 对于使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+  \sa Dtk::Gui::DPlatformHandle::enableDXcbForWindow
+  \sa Dtk::Gui::DPlatformHandle::isEnabledDXcb
+
+  \value FUNC_MOVE
+  控制窗口位置。如果存在此标志，则窗口管理器可以移动窗口（如使用鼠标拖动标题栏），否则
+  无法通过外部行为移动窗口位置。
+  \code
+  DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_MOVE, false);
+  \endcode
+  \image disable_move_function.gif
+
+  \value FUNC_MINIMIZE
+  最小化窗口。如果存在此标志，则窗口可以被最小化（如点击标题栏的最小化按钮），否则无法
+  通过外部行为最小化窗口。
+  \code
+  DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_MINIMIZE, false);
+  \endcode
+  \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
+
+  \value FUNC_MAXIMIZE
+  最大化窗口。如果存在此标志，则窗口可以被最大化（如点击标题栏的最大化按钮），否则无法
+  通过外部行为最大化窗口。
+  \code
+  DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_MAXIMIZE, false);
+  \endcode
+  \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
+
+  \value FUNC_CLOSE
+  关闭窗口。如果存在此标志，则窗口可以被关闭（如点击标题栏的关闭按钮或使用Alt+F4快捷键），
+  否则无法通过外部行为关闭窗口。
+  \code
+  DWindowManagerHelper::setMotifFunctions(w.windowHandle(), DWindowManagerHelper::FUNC_CLOSE, false);
+  \endcode
+  \note 设置此标志后也会影响窗口标题栏对应功能入口的状态
+
+  \value FUNC_ALL
+  所有功能性行为
  */
 
 /*!
- * \~chinese \enum DWindowManagerHelper::MotifDecoration
- * \~chinese MotifFunction::MotifDecoration 窗口管理器对窗口添加的修饰。只影响窗口上对应功能
- * \~chinese 的入口，不影响实际的功能，比如：禁用掉 FUNC_MAXIMIZE 后，还可以使用快捷键最大化窗口
- *
- * \~chinese \var DWindowManagerHelper::DECOR_BORDER DWindowManagerHelper::DECOR_BORDER
- * \~chinese 窗口描边。如果存在此标志，则窗口管理器会为窗口绘制描边，否则窗口没有描边。
- * \~chinese 否则无法通过外部行为调整窗口大小。
- * \~chinese \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- *
- * \~chinese \var DWindowManagerHelper::DECOR_RESIZEH DWindowManagerHelper::DECOR_RESIZEH
- * \~chinese 改变窗口大小。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个更改窗口大小的控件，
- * \~chinese 否则无此控件。
- * \~chinese \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- *
- * \~chinese \var DWindowManagerHelper::DECOR_TITLE DWindowManagerHelper::DECOR_TITLE
- * \~chinese 窗口标题。如果存在此标志，则窗口管理器会在窗口的修饰上显示窗口标题，否则不显示。
- * \~chinese \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- *
- * \~chinese \var DWindowManagerHelper::DECOR_MENU DWindowManagerHelper::DECOR_MENU
- * \~chinese 窗口菜单。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个窗口菜单控件，否则不显示。
- * \~chinese \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- *
- * \~chinese \var DWindowManagerHelper::DECOR_MINIMIZE DWindowManagerHelper::DECOR_MINIMIZE
- * \~chinese 窗口最小化。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个最小化窗口控件，否则不显示。
- * \~chinese \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- * \~chinese \sa Qt::WindowMinimizeButtonHint
- *
- * \~chinese \var DWindowManagerHelper::DECOR_MAXIMIZE DWindowManagerHelper::DECOR_MAXIMIZE
- * \~chinese 窗口最大化。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个最大化窗口控件，否则不显示。
- * \~chinese \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
- * \~chinese 此标志无效。
- * \~chinese \sa Qt::WindowMaximizeButtonHint
- *
- * \~chinese \var DWindowManagerHelper::DECOR_ALL DWindowManagerHelper::DECOR_ALL
- * \~chinese 所有窗口修饰。
+  \enum Dtk::Gui::DWindowManagerHelper::MotifDecoration
+  MotifFunction::MotifDecoration 窗口管理器对窗口添加的修饰。只影响窗口上对应功能
+  的入口，不影响实际的功能，比如：禁用掉 FUNC_MAXIMIZE 后，还可以使用快捷键最大化窗口
+
+  \value DECOR_BORDER
+  窗口描边。如果存在此标志，则窗口管理器会为窗口绘制描边，否则窗口没有描边。
+  否则无法通过外部行为调整窗口大小。
+  \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+
+  \value DECOR_RESIZEH
+  改变窗口大小。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个更改窗口大小的控件，
+  否则无此控件。
+  \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+
+  \value DECOR_TITLE
+  窗口标题。如果存在此标志，则窗口管理器会在窗口的修饰上显示窗口标题，否则不显示。
+  \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+
+  \value DECOR_MENU
+  窗口菜单。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个窗口菜单控件，否则不显示。
+  \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+
+  \value DECOR_MINIMIZE
+  窗口最小化。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个最小化窗口控件，否则不显示。
+  \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+  \sa Qt::WindowMinimizeButtonHint
+
+  \value DECOR_MAXIMIZE
+  窗口最大化。如果存在此标志，则窗口管理器会在窗口的修饰上显示一个最大化窗口控件，否则不显示。
+  \note 只支持使用系统标题栏的窗口，此功能和具体窗口管理器实现相关，deepin-wm 中设置
+  此标志无效。
+  \sa Qt::WindowMaximizeButtonHint
+
+  \value DECOR_ALL
+  所有窗口修饰。
  */
 
 /*!
- * \~chinese \enum DWindowManagerHelper::WMName
- * \~chinese DWindowManagerHelper::WMName 窗口管理器类型
- * \~chinese \var DWindowManagerHelper::DeepinWM DWindowManagerHelper::DeepinWM
- * \~chinese 深度系统桌面环境窗口管理器
- *
- * \~chinese \var DWindowManagerHelper::DeepinWM DWindowManagerHelper::KWinWM
- * \~chinese KDE系统桌面环境窗口管理器
- *
- * \~chinese \var DWindowManagerHelper::DeepinWM DWindowManagerHelper::OtherWM
- * \~chinese 其它窗口管理器
+  \enum Dtk::Gui::DWindowManagerHelper::WMName
+  DWindowManagerHelper::WMName 窗口管理器类型
+  \value DeepinWM
+  深度系统桌面环境窗口管理器
+
+  \value KWinWM
+  KDE系统桌面环境窗口管理器
+
+  \value OtherWM
+  其它窗口管理器
  */
 
 /*!
- * \~chinese \fn DWindowManagerHelper::windowManagerChanged
- * \~chinese \brief 信号会在当前环境窗口管理器变化时被发送
- * \~chinese \fn DWindowManagerHelper::hasBlurWindowChanged
- * \~chinese \brief 信号会在 hasBlurWindow 属性的值改变时被发送
- * \~chinese \fn DWindowManagerHelper::hasCompositeChanged
- * \~chinese \brief 信号会在 hasComposite 属性的值改变时被发送
- * \~chinese \fn DWindowManagerHelper::hasNoTitlebarChanged
- * \~chinese \brief 信号会在 hasNoTitlebar 属性的值改变时被发送
- * \~chinese \fn DWindowManagerHelper::hasWallpaperEffectChanged
- * \~chinese \brief 信号会在 hasWallpaperEffect 属性的值改变时被发送
- * \~chinese \fn DWindowManagerHelper::windowListChanged
- * \~chinese \brief 信号会在当前环境本地窗口列表变化时被发送。包含打开新窗口、关闭窗口、改变窗口的
- * \~chinese 层叠顺序
- * \~chinese \fn DWindowManagerHelper::windowMotifWMHintsChanged
- * \~chinese \brief 信号会在窗口功能或修饰标志改变时被发送
- * \~chinese \param 窗口id
- * \~chinese \note 只对当前应用程序中的窗口有效
+  \fn void DWindowManagerHelper::windowManagerChanged()
+  \brief 信号会在当前环境窗口管理器变化时被发送.
+ */
+/*!
+  \fn void DWindowManagerHelper::hasBlurWindowChanged()
+  \brief 信号会在 hasBlurWindow 属性的值改变时被发送.
+ */
+/*!
+  \fn void DWindowManagerHelper::hasCompositeChanged()
+  \brief 信号会在 hasComposite 属性的值改变时被发送.
+ */
+/*!
+  \fn void DWindowManagerHelper::hasNoTitlebarChanged()
+  \brief 信号会在 hasNoTitlebar 属性的值改变时被发送.
+ */
+/*!
+  \fn void DWindowManagerHelper::hasWallpaperEffectChanged()
+  \brief 信号会在 hasWallpaperEffect 属性的值改变时被发送.
+ */
+/*!
+  \fn void DWindowManagerHelper::windowListChanged()
+  \brief 信号会在当前环境本地窗口列表变化时被发送。包含打开新窗口、关闭窗口、改变窗口的
+  层叠顺序.
+ */
+/*!
+  \fn void DWindowManagerHelper::windowMotifWMHintsChanged(quint32 winId)
+  \brief 信号会在窗口功能或修饰标志改变时被发送.
+
+  \a winId 窗口id
+  \note 只对当前应用程序中的窗口有效
  */
 
 DWindowManagerHelper::~DWindowManagerHelper()
@@ -340,9 +336,9 @@ DWindowManagerHelper::~DWindowManagerHelper()
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::instance
- * \~chinese DWindowManagerHelper 的单例对象，使用 Q_GLOBAL_STATIC 定义，在第一次调用时实例化。
- * \~chinese \return
+  \brief DWindowManagerHelper::instance
+  DWindowManagerHelper 的单例对象，使用 Q_GLOBAL_STATIC 定义，在第一次调用时实例化。
+  \return
  */
 DWindowManagerHelper *DWindowManagerHelper::instance()
 {
@@ -350,10 +346,10 @@ DWindowManagerHelper *DWindowManagerHelper::instance()
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::setMotifFunctions
- * \~chinese 设置窗口的功能性标志，会覆盖之前的设置
- * \~chinese \param window
- * \~chinese \param hints
+  \brief DWindowManagerHelper::setMotifFunctions
+  设置窗口的功能性标志，会覆盖之前的设置
+  \a window
+  \a hints
  */
 void DWindowManagerHelper::setMotifFunctions(const QWindow *window, MotifFunctions hints)
 {
@@ -365,9 +361,9 @@ void DWindowManagerHelper::setMotifFunctions(const QWindow *window, MotifFunctio
 
     if (setMWMFunctions && window->handle()) {
         /*
-     * fix bug: 18775, 3391
-     *  当所有function标志都设置时,用MWM_FUNC_ALL代替会导致窗管无法正确处理 dock栏发送的关闭消息.所以取消此设置
-     *
+  fix bug: 18775, 3391
+   当所有function标志都设置时,用MWM_FUNC_ALL代替会导致窗管无法正确处理 dock栏发送的关闭消息.所以取消此设置
+
      if (hints == FUNC_ALL)
          hints = (MotifFunction)MWM_FUNC_ALL;
     */
@@ -377,12 +373,12 @@ void DWindowManagerHelper::setMotifFunctions(const QWindow *window, MotifFunctio
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::setMotifFunctions
- * \~chinese 设置窗口某些标志位的开启状态，不影响其它标志位
- * \~chinese \param window
- * \~chinese \param hints 要设置的标志位
- * \~chinese \param on 如果值为 true 则开启标志，否则关闭
- * \~chinese \return 返回设置后的窗口标志
+  \brief DWindowManagerHelper::setMotifFunctions
+  设置窗口某些标志位的开启状态，不影响其它标志位
+  \a window
+  \a hints 要设置的标志位
+  \a on 如果值为 true 则开启标志，否则关闭
+  \return 返回设置后的窗口标志
  */
 DWindowManagerHelper::MotifFunctions DWindowManagerHelper::setMotifFunctions(const QWindow *window, MotifFunctions hints, bool on)
 {
@@ -399,9 +395,9 @@ DWindowManagerHelper::MotifFunctions DWindowManagerHelper::setMotifFunctions(con
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::getMotifFunctions
- * \~chinese \param window
- * \~chinese \return 返回窗口当前的功能标志
+  \brief DWindowManagerHelper::getMotifFunctions
+  \a window
+  \return 返回窗口当前的功能标志
  */
 DWindowManagerHelper::MotifFunctions DWindowManagerHelper::getMotifFunctions(const QWindow *window)
 {
@@ -422,10 +418,10 @@ DWindowManagerHelper::MotifFunctions DWindowManagerHelper::getMotifFunctions(con
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::setMotifDecorations
- * \~chinese 设置窗口的修饰性标志，会覆盖之前的设置
- * \~chinese \param window
- * \~chinese \param hints
+  \brief DWindowManagerHelper::setMotifDecorations
+  设置窗口的修饰性标志，会覆盖之前的设置
+  \a window
+  \a hints
  */
 void DWindowManagerHelper::setMotifDecorations(const QWindow *window, MotifDecorations hints)
 {
@@ -444,12 +440,12 @@ void DWindowManagerHelper::setMotifDecorations(const QWindow *window, MotifDecor
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::setMotifFunctions
- * \~chinese 设置窗口某些标志位的开启状态，不影响其它标志位
- * \~chinese \param window
- * \~chinese \param hints 要设置的标志位
- * \~chinese \param on 如果值为 true 则开启标志，否则关闭
- * \~chinese \return 返回设置后的窗口标志
+  \brief DWindowManagerHelper::setMotifFunctions
+  设置窗口某些标志位的开启状态，不影响其它标志位
+  \a window
+  \a hints 要设置的标志位
+  \a on 如果值为 true 则开启标志，否则关闭
+  \return 返回设置后的窗口标志
  */
 DWindowManagerHelper::MotifDecorations DWindowManagerHelper::setMotifDecorations(const QWindow *window, MotifDecorations hints, bool on)
 {
@@ -466,9 +462,9 @@ DWindowManagerHelper::MotifDecorations DWindowManagerHelper::setMotifDecorations
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::getMotifFunctions
- * \~chinese \param window
- * \~chinese \return 返回窗口当前的修饰标志
+  \brief DWindowManagerHelper::getMotifFunctions
+  \a window
+  \return 返回窗口当前的修饰标志
  */
 DWindowManagerHelper::MotifDecorations DWindowManagerHelper::getMotifDecorations(const QWindow *window)
 {
@@ -489,11 +485,11 @@ DWindowManagerHelper::MotifDecorations DWindowManagerHelper::getMotifDecorations
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::setWmWindowTypes
- * \~chinese 直接设置窗口管理器层级提供的窗口类型，如DesktopType和DockType类型也被
- * \~chinese 桌面环境需要，但是Qt自身并没有提供对应的设置接口
- * \~chinese \param window
- * \~chinese \param types
+  \brief DWindowManagerHelper::setWmWindowTypes
+  直接设置窗口管理器层级提供的窗口类型，如DesktopType和DockType类型也被
+  桌面环境需要，但是Qt自身并没有提供对应的设置接口
+  \a window
+  \a types
  */
 void DWindowManagerHelper::setWmWindowTypes(QWindow *window, WmWindowTypes types)
 {
@@ -502,11 +498,11 @@ void DWindowManagerHelper::setWmWindowTypes(QWindow *window, WmWindowTypes types
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::setWmClassName
- * \~chinese 设置x11环境上默认使用的wm class name，主要是在窗口创建时用于设置WM_CLASS窗口属性
- * \~chinese \param name
- * \~chinese \note 如果值为空，Qt将在下次使用此值时根据程序名称再次初始化此值
- * \~chinese \sa QCoreApplication::applicationName
+  \brief DWindowManagerHelper::setWmClassName
+  设置x11环境上默认使用的wm class name，主要是在窗口创建时用于设置WM_CLASS窗口属性
+  \a name
+  \note 如果值为空，Qt将在下次使用此值时根据程序名称再次初始化此值
+  \sa QCoreApplication::applicationName
  */
 void DWindowManagerHelper::setWmClassName(const QByteArray &name)
 {
@@ -515,11 +511,11 @@ void DWindowManagerHelper::setWmClassName(const QByteArray &name)
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::popupSystemWindowMenu
- * \~chinese 显示窗口管理器对窗口的菜单，和有边框的窗口在标题栏上点击鼠标右键弹出的菜单内容一致。
- * \~chinese 在 DMainWindow 的标题栏上点击鼠标右键会调用此函数打开系统菜单：
- * \~chinese \image html window_system_menu.gif
- * \~chinese \param window
+  \brief DWindowManagerHelper::popupSystemWindowMenu
+  显示窗口管理器对窗口的菜单，和有边框的窗口在标题栏上点击鼠标右键弹出的菜单内容一致。
+  在 DMainWindow 的标题栏上点击鼠标右键会调用此函数打开系统菜单：
+  \image window_system_menu.gif
+  \a window
  */
 void DWindowManagerHelper::popupSystemWindowMenu(const QWindow *window)
 {
@@ -535,8 +531,8 @@ void DWindowManagerHelper::popupSystemWindowMenu(const QWindow *window)
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::hasBlurWindow
- * \~chinese \return 如果当前窗口管理器支持窗口背景模糊特效则返回 true，否则返回 false
+  \brief DWindowManagerHelper::hasBlurWindow
+  \return 如果当前窗口管理器支持窗口背景模糊特效则返回 true，否则返回 false
  */
 bool DWindowManagerHelper::hasBlurWindow() const
 {
@@ -550,8 +546,8 @@ bool DWindowManagerHelper::hasBlurWindow() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::hasComposite
- * \~chinese \return 如果当前窗口管理器支持混成则返回 true，否则返回 false
+  \brief DWindowManagerHelper::hasComposite
+  \return 如果当前窗口管理器支持混成则返回 true，否则返回 false
  */
 bool DWindowManagerHelper::hasComposite() const
 {
@@ -579,8 +575,8 @@ bool DWindowManagerHelper::hasComposite() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::hasNoTitlebar
- * \~chinese \return 如果窗口管理器当前支持设置隐藏窗口标题栏则返回 true，否则返回 false
+  \brief DWindowManagerHelper::hasNoTitlebar
+  \return 如果窗口管理器当前支持设置隐藏窗口标题栏则返回 true，否则返回 false
  */
 bool DWindowManagerHelper::hasNoTitlebar() const
 {
@@ -594,8 +590,8 @@ bool DWindowManagerHelper::hasNoTitlebar() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::hasWallpaperEffect
- * \~chinese \return 如果窗口管理器当前支持背景图片特效绘制返回 true，否则返回 false
+  \brief DWindowManagerHelper::hasWallpaperEffect
+  \return 如果窗口管理器当前支持背景图片特效绘制返回 true，否则返回 false
  */
 bool DWindowManagerHelper::hasWallpaperEffect() const
 {
@@ -609,11 +605,11 @@ bool DWindowManagerHelper::hasWallpaperEffect() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::windowManagerNameString
- * \~chinese \return 返回窗口管理器名称。在X11平台上，此值为窗口管理器对应窗口的 _NET_WM_NAME
- * \~chinese 的值
- * \~chinese \sa \href{https://specifications.freedesktop.org/wm-spec/1.3/ar01s03.html,_NET_SUPPORTING_WM_CHECK}
- * \~chinese \sa \href{https://specifications.freedesktop.org/wm-spec/1.3/ar01s05.html,_NET_WM_NAME}
+  \brief DWindowManagerHelper::windowManagerNameString
+  \return 返回窗口管理器名称。在X11平台上，此值为窗口管理器对应窗口的 _NET_WM_NAME
+  的值
+  \l {https://specifications.freedesktop.org/wm-spec/1.3/ar01s03.html}{_NET_SUPPORTING_WM_CHECK}
+  \l {https://specifications.freedesktop.org/wm-spec/1.3/ar01s05.html}{_NET_WM_NAME}
  */
 QString DWindowManagerHelper::windowManagerNameString() const
 {
@@ -627,9 +623,9 @@ QString DWindowManagerHelper::windowManagerNameString() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::windowManagerName
- * \~chinese \return 返回当前窗口管理器类型
- * \~chinese \sa DWindowManagerHelper::windowManagerNameString
+  \brief DWindowManagerHelper::windowManagerName
+  \return 返回当前窗口管理器类型
+  \sa DWindowManagerHelper::windowManagerNameString
  */
 DWindowManagerHelper::WMName DWindowManagerHelper::windowManagerName() const
 {
@@ -647,10 +643,10 @@ DWindowManagerHelper::WMName DWindowManagerHelper::windowManagerName() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::allWindowIdList
- * \~chinese \return 返回当前环境所有本地窗口的窗口id列表
- * \~chinese \note 顺序和窗口层叠顺序相关，显示越靠下层的窗口在列表中顺序越靠前
- * \~chinese \sa DWindowManagerHelper::currentWorkspaceWindowIdList
+  \brief DWindowManagerHelper::allWindowIdList
+  \return 返回当前环境所有本地窗口的窗口id列表
+  \note 顺序和窗口层叠顺序相关，显示越靠下层的窗口在列表中顺序越靠前
+  \sa DWindowManagerHelper::currentWorkspaceWindowIdList
  */
 QVector<quint32> DWindowManagerHelper::allWindowIdList() const
 {
@@ -666,10 +662,10 @@ QVector<quint32> DWindowManagerHelper::allWindowIdList() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::currentWorkspaceWindowIdList
- * \~chinese \return 返回当前工作区所有本地窗口的窗口id列表
- * \~chinese \note 顺序和窗口层叠顺序相关，显示越靠下层的窗口在列表中顺序越靠前
- * \~chinese \sa DWindowManagerHelper::allWindowIdList
+  \brief DWindowManagerHelper::currentWorkspaceWindowIdList
+  \return 返回当前工作区所有本地窗口的窗口id列表
+  \note 顺序和窗口层叠顺序相关，显示越靠下层的窗口在列表中顺序越靠前
+  \sa DWindowManagerHelper::allWindowIdList
  */
 QVector<quint32> DWindowManagerHelper::currentWorkspaceWindowIdList() const
 {
@@ -685,14 +681,14 @@ QVector<quint32> DWindowManagerHelper::currentWorkspaceWindowIdList() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::currentWorkspaceWindowIdList
- * \~chinese \return 返回当前工作区所有本地窗口对象列表。和 \a currentWorkspaceWindowIdList
- * \~chinese 类似，只不过自动通过窗口id创建了 DForeignWindow 对象
- * \~chinese \note 顺序和窗口层叠顺序相关，显示越靠下层的窗口在列表中顺序越靠前
- * \~chinese \note 列表中对象的生命周期由 DForeignWindow 负责
- * \~chinese \warning 此列表中不包含由当前应用创建的窗口
- * \~chinese \sa DWindowManagerHelper::currentWorkspaceWindowIdList
- * \~chinese \sa DForeignWindow::fromWinId
+  \brief DWindowManagerHelper::currentWorkspaceWindowIdList
+  \return 返回当前工作区所有本地窗口对象列表。和 currentWorkspaceWindowIdList
+  类似，只不过自动通过窗口id创建了 DForeignWindow 对象
+  \note 顺序和窗口层叠顺序相关，显示越靠下层的窗口在列表中顺序越靠前
+  \note 列表中对象的生命周期由 DForeignWindow 负责
+  \warning 此列表中不包含由当前应用创建的窗口
+  \sa DWindowManagerHelper::currentWorkspaceWindowIdList
+  \sa DForeignWindow::fromWinId
  */
 QList<DForeignWindow *> DWindowManagerHelper::currentWorkspaceWindows() const
 {
@@ -730,9 +726,9 @@ QList<DForeignWindow *> DWindowManagerHelper::currentWorkspaceWindows() const
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::windowFromPoint
- * \~chinese \return 返回 point 位置的窗口 Id，如果出错返回 0
- * \~chinese \note 可以通过 DForeignWindow::fromWinId 创建窗口对象
+  \brief DWindowManagerHelper::windowFromPoint
+  \return 返回 \a p 位置的窗口 Id，如果出错返回 0
+  \note 可以通过 DForeignWindow::fromWinId 创建窗口对象
  */
 quint32 DWindowManagerHelper::windowFromPoint(const QPoint &p)
 {
@@ -749,10 +745,10 @@ quint32 DWindowManagerHelper::windowFromPoint(const QPoint &p)
 }
 
 /*!
- * \~chinese \brief DWindowManagerHelper::DWindowManagerHelper
- * \~chinese 不允许直接实例化此对象
- * \~chinese \param parent
- * \~chinese \sa DWindowManagerHelper::instance
+  \brief DWindowManagerHelper::DWindowManagerHelper
+  不允许直接实例化此对象
+  \a parent
+  \sa DWindowManagerHelper::instance
  */
 DWindowManagerHelper::DWindowManagerHelper(QObject *parent)
     : QObject(parent)
