@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2021 UnionTech Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "ddciicon.h"
 #include "dguiapplicationhelper.h"
 #include "dicontheme.h"
@@ -249,6 +233,14 @@ public:
     EntryNodeList icons;
 };
 
+#ifndef QT_NO_DATASTREAM
+__attribute__((constructor))
+static void registerMetaType()
+{
+    qRegisterMetaTypeStreamOperators<DDciIcon>("DDciIcon");
+}
+#endif
+
 static inline bool toMode(const QStringRef &name, DDciIcon::Mode *mode) {
     if (name == QLatin1String(MODE_NORMAL)) {
         *mode = DDciIcon::Normal;
@@ -332,6 +324,8 @@ static QImage readImageData(const QByteArray &data, const QByteArray &format, qr
 
         if (!scaled)
             image = image.scaled(scaledSize, scaledSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    } else {
+        qWarning() << reader.errorString() << format;
     }
 
     return image;
@@ -534,7 +528,11 @@ void DDciIconPrivate::paint(QPainter *painter, const QRect &rect, qreal devicePi
     for (auto layerIter = targetData.layers.begin(); layerIter != targetData.layers.end(); ++layerIter) {
         if (layerIter->data.isEmpty())
             continue;
-        const QImage &layer = readImageData(layerIter->data, layerIter->format, pixmapScale * pixelRatio / targetData.imagePixelRatio, layerIter->isAlpha8Format);
+        qreal deviceRatio = 1.0;
+        if (qApp->testAttribute(Qt::AA_UseHighDpiPixmaps)) {
+            deviceRatio = pixelRatio;
+        }
+        const QImage &layer = readImageData(layerIter->data, layerIter->format, pixmapScale * deviceRatio / targetData.imagePixelRatio, layerIter->isAlpha8Format);
         if (layer.isNull())
             continue;
         QColor fillColor;
@@ -575,7 +573,12 @@ void DDciIconPrivate::paint(QPainter *painter, const QRect &rect, qreal devicePi
         painter->setRenderHint(QPainter::Antialiasing);
         QRect sourceRect(0, 0, layer.width(), layer.height());
         sourceRect.moveCenter(iconRect.center());
-        painter->drawImage(sourceRect, tmp);
+        QRect targetRect = sourceRect;
+        if (iconRect.width() < sourceRect.width())
+            targetRect = iconRect;
+
+        // Use AA_UseHighDpiPixmaps will solve blurred icon.
+        painter->drawImage(targetRect, tmp);
         painter->restore();
     }
 
@@ -711,7 +714,12 @@ QPixmap DDciIcon::pixmap(qreal devicePixelRatio, int iconSize, DDciIconMatchResu
 
     Q_ASSERT_X((iconSize > 0), "DDciIcon::generatePixmap", "You must specify the icon size.");
     const qreal pixmapScale = iconSize * 1.0 / entry->iconSize;
-    const int pixmapSize = qRound((findMaxEntryPadding(entry) * 2 + entry->iconSize) * pixmapScale * devicePixelRatio);
+
+    qreal deviceRatio = 1.0;
+    if (qApp->testAttribute(Qt::AA_UseHighDpiPixmaps)) {
+        deviceRatio = devicePixelRatio;
+    }
+    const int pixmapSize = qRound((findMaxEntryPadding(entry) * 2 + entry->iconSize) * pixmapScale * deviceRatio);
 
     QPixmap pixmap(pixmapSize, pixmapSize);
     pixmap.fill(Qt::transparent);
@@ -747,7 +755,8 @@ DDciIcon DDciIcon::fromTheme(const QString &name)
     DDciIcon icon;
 
     QString iconName = name;
-    if (!DSGApplication::id().isEmpty()) {
+    // FIX uengine appname is empty, will cause qt_assert
+    if (!QCoreApplication::applicationName().isEmpty() &&  !DSGApplication::id().isEmpty()) {
         // allow the icon theme to override the icon for a given application
         iconName.prepend(DSGApplication::id() + "/");
     }
@@ -776,4 +785,24 @@ DDciIcon DDciIcon::fromTheme(const QString &name, const DDciIcon &fallback)
     return icon;
 }
 
+#ifndef QT_NO_DATASTREAM
+QDataStream &operator<<(QDataStream &s, const DDciIcon &icon)
+{
+    if (icon.isNull())
+        return s << QByteArray();
+    auto dciFile = icon.d->dciFile;
+    const QByteArray &data = dciFile->toData();
+    s << data;
+    return s;
+}
+
+QDataStream &operator>>(QDataStream &s, DDciIcon &icon)
+{
+    QByteArray data;
+    s >> data;
+    icon = DDciIcon(data);
+    return s;
+}
+#endif
+
 DGUI_END_NAMESPACE
